![example workflow](https://github.com/github/docs/actions/workflows/test.yml/badge.svg)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
# EunomiA
LLM-based tool for predicting water stability of metal organic frameworks.

![TOC](https://github.com/AI4ChemS/Eunomia/assets/51170839/78525f9a-e544-4c04-b0a8-c24d84ca44f1)


Installation
--------

```python
pip install Eunomia@git+https://github.com/AI4ChemS/Eunomia.git
```

or you can clone the source code and install in developer mode:

```python
git clone https://github.com/AI4ChemS/Eunomia.git && cd Eunomia
pip install -e .
```

Authors
--------

`EunomiA` is developed by [Mehrad Ansari](https://mehradans92.github.io/).
